Changelog
=========

1.99.2
------
 - added aggregated filters support

1.99.1
------
 - removed index checker for search folders
 - added edit forms content getters

1.99.0.1
--------
 - packaging issue

1.99.0
------
 - first preliminary release
